﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Markup;

namespace SilverlightApplication1
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            List<StaffMember> dataList = StaffMember.GetData();
            dataGrid.AutoGenerateColumns = false;
            dataGrid.ItemsSource = dataList;
            dataGrid.Columns.Clear();

            dataGrid.Columns.Add(CreateTextColumn("Name", "Staff Name"));
            dataGrid.Columns.Add(CreateTextColumn("Department", "Company Department"));

            //in the real world you would have some kind of definition object to tell you how many columns to create
            //and not use the actuall first index of the object in the child collection
            int periodCount = dataList[0].Periods.Count;
            for (int i = 0; i < periodCount; i++)
            {
                //dataGrid.Columns.Add(CreateTemplateColumn(i, "Title"));
                dataGrid.Columns.Add(CreateTemplateColumn(i, "Hours"));
            }
        }

        private static DataGridTextColumn CreateTextColumn(string fieldName, string title)
        {
            DataGridTextColumn column = new DataGridTextColumn();
            column.Header = title;
            column.Binding = new System.Windows.Data.Binding(fieldName);
            return column;
        }

        private DataGridTemplateColumn CreateTemplateColumn(int i, string propName)
        {
            DataGridTemplateColumn column = new DataGridTemplateColumn();
            column.Header = String.Format("Period#{0}.{1}", i, propName);
            column.CellTemplate = (DataTemplate)XamlReader.Load(CreateColumnTemplate(i, propName)); //display template
            column.CellEditingTemplate = (DataTemplate)XamlReader.Load(CreateColumnEditTemplate(i, propName)); //edit template
            return column;
        }

        private string CreateColumnTemplate(int index, string propertyName)
        {
            StringBuilder CellTemp = new StringBuilder();
            CellTemp.Append("<DataTemplate ");
            CellTemp.Append("xmlns='http://schemas.microsoft.com/winfx/");
            CellTemp.Append("2006/xaml/presentation' ");
            CellTemp.Append("xmlns:x='http://schemas.microsoft.com/winfx/2006/xaml'>");
            CellTemp.Append(String.Format("<TextBlock Text='{{Binding Periods[{0}].{1}}}'/>", index, propertyName));
            CellTemp.Append("</DataTemplate>");
            return CellTemp.ToString();
        }

        private string CreateColumnEditTemplate(int index, string propertyName)
        {
            StringBuilder CellTemp = new StringBuilder();
            CellTemp.Append("<DataTemplate ");
            CellTemp.Append("xmlns='http://schemas.microsoft.com/winfx/");
            CellTemp.Append("2006/xaml/presentation' ");
            CellTemp.Append("xmlns:x='http://schemas.microsoft.com/winfx/2006/xaml'>");
            CellTemp.Append(String.Format("<TextBox Text='{{Binding Periods[{0}].{1}, Mode=TwoWay}}'/>", index, propertyName));
            CellTemp.Append("</DataTemplate>");
            return CellTemp.ToString();
        }
    }
}
